/*---------------------------------------------------------------------------\
| Project:			Generic LV2 PIC18F458 CAN node firmware
|
| File:				ports.c
|
| Description:		Code which deals with the PIC18F458's I/O ports.
|
| Global Routines:	InitializePorts()
|
| Local Routines:	None
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 06/01/2002 | Stolen from ADG code.
\---------------------------------------------------------------------------*/



//------------------------------------------------------------------------
//  #includes
//------------------------------------------------------------------------

#include <p18f458.h>    // Register definitions for the PIC18F458
#include "project.h"	// Includes for the project (misc)
#include "ints.h"		// Includes for interrupts
#include "ports.h"		// Includes for the port peripherals
#include "excepts.h"	// Includes for exception handling




/*---------------------------------------------------------------------------\
| Function:		InitializePorts
|
| Purpose:		Initialize the PIC's ports out of reset.
|
| Discussion:	Huh?
|
| Expects:		All interupts to be off (after all, we were just reseted).
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 05/21/2002 | Created if you can call it that.
\---------------------------------------------------------------------------*/

void InitializePorts (void)
{

	//------------------------------------------------------------------------
	// PORTA: RA0 - RA5 (Caution: ADC, RA5)
	//------------------------------------------------------------------------

	LATA = 0;				// Port A output latch = all zeros
	ADCON1 = 0b00000110;	// Tell ADC peripheral to give up PORTA pins to PORTA
		 	// ||||||||
			// |||||||+----------- PCFG0 = 0110 = Port A is ALL digital outputs
		    // ||||||+------------ PCFG1    	  (i.e., not ADC inputs)
		    // |||||+------------- PCFG2
		    // ||||+-------------- PCFG3
		    // |||+--------------- <Unimplemented on PIC>
			// ||+---------------- <Unimplemented on PIC>
		    // |+----------------- ADCS2 = x
		    // +------------------ ADFM = x
	TRISA = 0;				// PORTA is all outputs.



	//------------------------------------------------------------------------
	// PORTB: RB0 - RB7 (Caution: ICD, CAN)
	//------------------------------------------------------------------------

	LATB = 0;				// Port B output latch = all zeros
	INTCON2bits.RBPU = 1;	// Turn OFF Port B weak (~60kohm) pull-up resistors
	TRISB =  0b00001000;	// Set direction of PORTB pins
		 	// ||||||||
			// |||||||+----------- RB0/INT0 = out (not used)
		    // ||||||+------------ RB1/INT1 = out (not used)
		    // |||||+------------- RB2/CANTX = out
		    // ||||+-------------- RB3/CANRX = in
		    // |||+--------------- RB4 = x
			// ||+---------------- RB5/PGM = x
		    // |+----------------- RB6/PGC = x (ICD2)
		    // +------------------ RB7/PGD = x (ICD2)



	//------------------------------------------------------------------------
	// PORTC: RC0 - RC7 (Caution: serial)
	//------------------------------------------------------------------------

	LATC = 0;	// Port C output latch = all zeros
	TRISC = 0;	// Port C all outputs



	//------------------------------------------------------------------------
	// PORTD: RD0 - RD7
	//------------------------------------------------------------------------

	LATD = 0;	// Port D output latch = all zeros
	TRISD = 0;	// Port D all outputs



	//------------------------------------------------------------------------
	// PORTE: RE0 - RE2
	//------------------------------------------------------------------------


	LATE = 0;	// Port E output latch = all zeros
	TRISE = 0;	// Port E all outputs
}



